@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "highlight-refontification" "0.0.4"
+(define-package "highlight-refontification" "20250104.1619"
   "Visualize refontification."
   ()
   :url "https://github.com/Lindydancer/highlight-refontification"
